@@ -23,7 +23,7 @@
 #define EMAILEDITWIDGET_H
 
 #include <kdialog.h>
-
+#include <kabc/email.h>
 namespace KABC
 {
 class Addressee;
@@ -59,7 +59,7 @@ private Q_SLOTS:
 private:
     KLineEdit *mEmailEdit;
     QToolButton *mEditButton;
-    QStringList mEmailList;
+    KABC::Email::List mList;
 };
 
 class EmailEditDialog : public KDialog
@@ -67,12 +67,14 @@ class EmailEditDialog : public KDialog
     Q_OBJECT
 
 public:
-    explicit EmailEditDialog(const QStringList &list, QWidget *parent = 0);
+    explicit EmailEditDialog(QWidget *parent = 0);
     ~EmailEditDialog();
 
-    QStringList emails() const;
     bool changed() const;
 
+
+    KABC::Email::List emailList() const;
+    void setEmailList(const KABC::Email::List &list);
 protected Q_SLOTS:
     void add();
     void edit();
