@@ -33,6 +33,7 @@
 
 #include "akonadiprivate_export.h"
 
+#include <kdebug.h>
 #include <qobject.h>
 #include <QQueue>
 #include <QVariant>
@@ -194,8 +195,11 @@ private:
 
     void processResult(KJob *job)
     {
-        // Error handling?
         typename T::Id id = job->property("EntityCacheNode").template value<typename T::Id>();
+        // Error handling?
+        if ( job->error() ) {
+          kWarning() << job->errorString();
+        }
         EntityCacheNode<T> *node = cacheNodeForId(id);
         if (!node) {
             return; // got replaced in the meantime
@@ -458,6 +462,9 @@ private:
 
     void processResult(KJob *job)
     {
+        if ( job->error() ) {
+          kWarning() << job->errorString();
+        }
         const QList<Entity::Id> ids = job->property("EntityListCacheIds").value< QList<Entity::Id> >();
 
         typename T::List entities;
