@@ -45,7 +45,6 @@ static bool matchBinaryPattern( int value, int pattern );
 template <class L>
 static bool listEquals( const QList<L>&, const QList<L>& );
 static bool listEquals( const QStringList&, const QStringList& );
-static bool emailsEquals( const QStringList&, const QStringList& );
 
 class Addressee::Private : public QSharedData
 {
@@ -100,6 +99,14 @@ class Addressee::Private : public QSharedData
       mGender = other.mGender;
       mCategories = other.mCategories;
       mCustomFields = other.mCustomFields;
+      mCalendarUrl = other.mCalendarUrl;
+      mSoundListExtra = other.mSoundListExtra;
+      mPhotoListExtra = other.mPhotoListExtra;
+      mLogoListExtra = other.mLogoListExtra;
+      mUrlListExtra = other.mUrlListExtra;
+      mSources = other.mSources;
+      mMembers = other.mMembers;
+      mRelationShips = other.mRelationShips;
 
 #ifndef KDEPIM_NO_KRESOURCES
       mResource = other.mResource;
@@ -148,6 +155,15 @@ class Addressee::Private : public QSharedData
     QString mKind;
     QStringList mCategories;
     QMap<QString, QString> mCustomFields;
+    CalendarUrl::List mCalendarUrl;
+
+    Sound::List mSoundListExtra;
+    Picture::List mPhotoListExtra;
+    Picture::List mLogoListExtra;
+    QList<KUrl> mUrlListExtra;
+    QStringList mMembers;
+    QStringList mRelationShips;
+    QList<KUrl> mSources;
 
 #ifndef KDEPIM_NO_KRESOURCES
     Resource *mResource;
@@ -369,7 +385,38 @@ bool Addressee::operator==( const Addressee &addressee ) const
     kDebug() << "kind differs";
     return false;
   }
-
+  if ( !listEquals( d->mCalendarUrl, addressee.d->mCalendarUrl ) ) {
+    kDebug() << "calendarUrl differs";
+    return false;
+  }
+  if ( !listEquals( d->mSoundListExtra, addressee.d->mSoundListExtra ) ) {
+    kDebug() << "Extra sound differs";
+    return false;
+  }
+  if ( !listEquals( d->mPhotoListExtra, addressee.d->mPhotoListExtra ) ) {
+    kDebug() << "Extra photo differs";
+    return false;
+  }
+  if ( !listEquals( d->mLogoListExtra, addressee.d->mLogoListExtra ) ) {
+    kDebug() << "Extra logo differs";
+    return false;
+  }
+  if ( !listEquals( d->mUrlListExtra, addressee.d->mUrlListExtra ) ) {
+    kDebug() << "Extra url differs";
+    return false;
+  }
+  if (!listEquals( d->mMembers, addressee.d->mMembers)) {
+      kDebug() << "Members differs";
+      return false;
+  }
+  if (!listEquals( d->mRelationShips, addressee.d->mRelationShips)) {
+      kDebug() << "RelationShips differs";
+      return false;
+  }
+  if (!listEquals( d->mSources, addressee.d->mSources)) {
+      kDebug() << "Sources differs";
+      return false;
+  }
   return true;
 }
 
@@ -430,12 +477,96 @@ void Addressee::setKind( const QString &kind )
   d->mKind = kind;
 }
 
+void Addressee::insertCalendarUrl(const CalendarUrl &calendarUrl)
+{
+    d->mEmpty = false;
+    //TODO verify that there is not same calendarurl
+    if (calendarUrl.isValid()) {
+        d->mCalendarUrl.append(calendarUrl);
+    }
+}
+
+void Addressee::insertExtraSound(const Sound &sound)
+{
+    d->mSoundListExtra.append(sound);
+}
+
+void Addressee::setExtraSoundList(const KABC::Sound::List &soundList)
+{
+    d->mSoundListExtra = soundList;
+}
+
+KABC::Sound::List Addressee::extraSoundList() const
+{
+    return d->mSoundListExtra;
+}
+
+void Addressee::insertExtraPhoto(const Picture &picture)
+{
+    d->mPhotoListExtra.append(picture);
+}
+
+void Addressee::setExtraPhotoList(const Picture::List &pictureList)
+{
+    d->mPhotoListExtra = pictureList;
+}
+
+Picture::List Addressee::extraPhotoList() const
+{
+    return d->mPhotoListExtra;
+}
+
+void Addressee::insertExtraLogo(const Picture &logo)
+{
+    d->mLogoListExtra.append(logo);
+}
+
+void Addressee::setExtraLogoList(const Picture::List &logoList)
+{
+    d->mLogoListExtra = logoList;
+}
+
+Picture::List Addressee::extraLogoList() const
+{
+    return d->mLogoListExtra;
+}
+
+void Addressee::insertExtraUrl(const KUrl &url)
+{
+    d->mUrlListExtra.append(url);
+}
+
+void Addressee::setExtraUrlList(const QList<KUrl> &urlList)
+{
+    d->mUrlListExtra = urlList;
+}
+
+QList<KUrl> Addressee::extraUrlList() const
+{
+    return d->mUrlListExtra;
+}
+
+void Addressee::insertSourceUrl(const KUrl &url)
+{
+    d->mSources.append(url);
+}
+
+void Addressee::setSourcesUrlList(const QList<KUrl> &urlList)
+{
+    d->mSources = urlList;
+}
+
+QList<KUrl> Addressee::sourcesUrlList() const
+{
+    return d->mSources;
+}
+
+
 QString Addressee::kind() const
 {
   return d->mKind;
 }
 
-
 void Addressee::setFormattedName( const QString &formattedName )
 {
   if ( formattedName == d->mFormattedName )
@@ -1364,6 +1495,12 @@ void Addressee::insertLang( const Lang &language )
     d->mLangs.append( language );
 }
 
+void Addressee::setLangs(const Lang::List &langs)
+{
+    d->mLangs = langs;
+    d->mEmpty = false;
+}
+
 Lang::List Addressee::langs() const
 {
     return d->mLangs;
@@ -1709,6 +1846,48 @@ Address Addressee::findAddress( const QString &id ) const
   return Address();
 }
 
+void Addressee::insertMember( const QString & member)
+{
+    d->mEmpty = false;
+
+    if ( d->mMembers.contains( member ) )
+      return;
+
+    d->mMembers.append( member );
+}
+
+void Addressee::setMembers( const QStringList &m )
+{
+  d->mEmpty = false;
+  d->mMembers = m;
+}
+
+QStringList Addressee::members() const
+{
+    return d->mMembers;
+}
+
+void Addressee::insertRelationShip(const QString &relation)
+{
+    d->mEmpty = false;
+
+    if ( d->mRelationShips.contains( relation ) )
+      return;
+
+    d->mRelationShips.append( relation );
+}
+
+void Addressee::setRelationShips(const QStringList &c)
+{
+    d->mEmpty = false;
+    d->mRelationShips = c;
+}
+
+QStringList Addressee::relationShips() const
+{
+    return d->mRelationShips;
+}
+
 void Addressee::insertCategory( const QString &c )
 {
   d->mEmpty = false;
@@ -2039,6 +2218,14 @@ QDataStream &KABC::operator<<( QDataStream &s, const Addressee &a )
   s << a.d->mLangs;
   s << a.d->mGender;
   s << a.d->mKind;
+  s << a.d->mCalendarUrl;
+  s << a.d->mSoundListExtra;
+  s << a.d->mPhotoListExtra;
+  s << a.d->mLogoListExtra;
+  s << a.d->mUrlListExtra;
+  s << a.d->mMembers;
+  s << a.d->mRelationShips;
+  s << a.d->mSources;
   return s;
 }
 
@@ -2082,6 +2269,14 @@ QDataStream &KABC::operator>>( QDataStream &s, Addressee &a )
   s >> a.d->mLangs;
   s >> a.d->mGender;
   s >> a.d->mKind;
+  s >> a.d->mCalendarUrl;
+  s >> a.d->mSoundListExtra;
+  s >> a.d->mPhotoListExtra;
+  s >> a.d->mLogoListExtra;
+  s >> a.d->mUrlListExtra;
+  s >> a.d->mMembers;
+  s >> a.d->mRelationShips;
+  s >> a.d->mSources;
   a.d->mEmpty = false;
 
   return s;
@@ -2130,25 +2325,3 @@ bool listEquals( const QStringList &list, const QStringList &pattern )
 
   return true;
 }
-
-bool emailsEquals( const QStringList &list, const QStringList &pattern )
-{
-  if ( list.count() != pattern.count() )
-    return false;
-
-  if ( list.isEmpty() )
-    return true;
-
-  if ( list.first() != pattern.first() )
-    return false;
-
-  QStringList::ConstIterator it;
-  QStringList::ConstIterator end( list.constEnd() );
-  for ( it = list.constBegin(); it != end; ++it ) {
-    if ( !pattern.contains( *it ) ) {
-      return false;
-    }
-  }
-
-  return true;
-}
