@@ -1,6 +1,7 @@
 /*
     This file is part of libkabc.
     Copyright (c) 2003 Tobias Koenig <tokoe@kde.org>
+    Copyright (c) 2015 Laurent Montel <montel@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -85,6 +86,17 @@ QByteArray VCardTool::createVCards( const Addressee::List &list, VCard::Version
   return createVCards( list, version, false /*don't export*/);
 }
 
+void VCardTool::addParameter(VCardLine &line, VCard::Version version, const QString &key, const QStringList &valueStringList) const
+{
+    if (version == VCard::v2_1) {
+        Q_FOREACH(const QString &valueStr, valueStringList) {
+            line.addParameter( valueStr, QString() );
+        }
+    } else {
+        line.addParameter( key, valueStringList.join(QLatin1String(",")) );
+    }
+}
+
 QByteArray VCardTool::createVCards( const Addressee::List &list,
                                     VCard::Version version, bool exportVcard ) const
 {
@@ -147,9 +159,9 @@ QByteArray VCardTool::createVCards( const Addressee::List &list,
       for ( typeIt = mAddressTypeMap.constBegin();
             typeIt != mAddressTypeMap.constEnd(); ++typeIt ) {
         if ( typeIt.value() & ( *it ).type() ) {
-          adrLine.addParameter( QLatin1String( "TYPE" ), typeIt.key() );
+            addParameter(adrLine, version, QLatin1String( "TYPE" ), QStringList()<<typeIt.key());
           if ( hasLabel ) {
-            labelLine.addParameter( QLatin1String( "TYPE" ), typeIt.key() );
+              addParameter(labelLine, version, QLatin1String( "TYPE" ), QStringList()<<typeIt.key());
           }
         }
       }
@@ -165,19 +177,47 @@ QByteArray VCardTool::createVCards( const Addressee::List &list,
     // BDAY
     card.addLine( VCardLine( QLatin1String( "BDAY" ), createDateTime( ( *addrIt ).birthday() ) ) );
 
+    //Laurent: 31 Jan 2015. Not necessary to export it. When Categories were changes as AkonadiTag nobody thought that it was break categorie support...
+    //=> not necessary to export just tag...
     // CATEGORIES only > 2.1
-    if ( version != VCard::v2_1 ) {
-      QStringList categories = ( *addrIt ).categories();
-      QStringList::Iterator catIt;
-      QStringList::Iterator catEnd( categories.end() );
-      for ( catIt = categories.begin(); catIt != catEnd; ++catIt ) {
-        ( *catIt ).replace( QLatin1Char( ',' ), QLatin1String( "\\," ) );
-      }
+    if (!exportVcard) {
+        if ( version != VCard::v2_1 ) {
+            QStringList categories = ( *addrIt ).categories();
+            QStringList::Iterator catIt;
+            QStringList::Iterator catEnd( categories.end() );
+            for ( catIt = categories.begin(); catIt != catEnd; ++catIt ) {
+                ( *catIt ).replace( QLatin1Char( ',' ), QLatin1String( "\\," ) );
+            }
 
-      VCardLine catLine( QLatin1String( "CATEGORIES" ), categories.join( QLatin1String( "," ) ) );
-      card.addLine( catLine );
+            VCardLine catLine( QLatin1String( "CATEGORIES" ), categories.join( QLatin1String( "," ) ) );
+            card.addLine( catLine );
+        }
     }
 
+    // MEMBER (only in 4.0)
+    if ( version == VCard::v4_0) {
+        // The KIND property must be set to "group" in order to use this property.
+        if (( *addrIt ).kind().toLower() == QLatin1String("group")) {
+            Q_FOREACH (const QString &member, ( *addrIt ).members() ) {
+                VCardLine line( QLatin1String( "MEMBER" ), member );
+                card.addLine( line );
+            }
+        }
+    }
+
+    // SOURCE
+    Q_FOREACH (const KUrl &url, ( *addrIt ).sourcesUrlList()) {
+        VCardLine line = VCardLine( QLatin1String( "SOURCE" ), url.url() );
+        card.addLine( line );
+    }
+
+    // RELATED
+    if (version == VCard::v4_0) {
+        Q_FOREACH (const QString &relation, ( *addrIt ).relationShips() ) {
+            VCardLine line( QLatin1String( "RELATED" ), relation );
+            card.addLine( line );
+        }
+    }
     // CLASS only for version == 3.0
     if ( version == VCard::v3_0 ) {
       card.addLine( createSecrecy( ( *addrIt ).secrecy() ) );
@@ -231,11 +271,19 @@ QByteArray VCardTool::createVCards( const Addressee::List &list,
                 foundType = true;
             }
             if (!valueStringList.isEmpty()) {
-                line.addParameter( i.key(), valueStringList.join(QLatin1String(",")) );
+                if (i.key().toLower() == QLatin1String( "type" )) {
+                    addParameter(line, version, i.key(), valueStringList);
+                } else {
+                    line.addParameter( i.key(), valueStringList.join(QLatin1String(",")) );
+                }
             }
         }
         if (!foundType && needToAddPref) {
-            line.addParameter( QLatin1String( "TYPE" ), QLatin1String( "PREF" ) );
+            if (version == VCard::v2_1) {
+                line.addParameter( QLatin1String( "PREF" ), QString() );
+            } else {
+                line.addParameter( QLatin1String( "TYPE" ), QLatin1String( "PREF" ) );
+            }
         }
         card.addLine( line );
     }
@@ -270,6 +318,9 @@ QByteArray VCardTool::createVCards( const Addressee::List &list,
 
     // LOGO
     card.addLine( createPicture( QLatin1String( "LOGO" ), ( *addrIt ).logo(), version ) );
+    Q_FOREACH (const KABC::Picture &logo, ( *addrIt ).extraLogoList()) {
+        card.addLine( createPicture( QLatin1String( "LOGO" ), logo, version ) );
+    }
 
     // MAILER only for version < 4.0
     if ( version != VCard::v4_0 ) {
@@ -349,6 +400,9 @@ QByteArray VCardTool::createVCards( const Addressee::List &list,
 
     // PHOTO
     card.addLine( createPicture( QLatin1String( "PHOTO" ), ( *addrIt ).photo(), version ) );
+    Q_FOREACH (const KABC::Picture &photo, ( *addrIt ).extraPhotoList()) {
+        card.addLine( createPicture( QLatin1String( "PHOTO" ), photo, version ) );
+    }
 
     // PROID only for version > 2.1
     if ( version != VCard::v2_1 ) {
@@ -373,6 +427,9 @@ QByteArray VCardTool::createVCards( const Addressee::List &list,
 
     // SOUND
     card.addLine( createSound( ( *addrIt ).sound(), version ) );
+    Q_FOREACH (const KABC::Sound &sound, ( *addrIt ).extraSoundList()) {
+        card.addLine( createSound( sound, version ) );
+    }
 
     // TEL
     const PhoneNumber::List phoneNumbers = ( *addrIt ).phoneNumbers();
@@ -385,7 +442,7 @@ QByteArray VCardTool::createVCards( const Addressee::List &list,
       QMap<QString, PhoneNumber::TypeFlag>::ConstIterator typeEnd( mPhoneTypeMap.constEnd() );
       for ( typeIt = mPhoneTypeMap.constBegin(); typeIt != typeEnd; ++typeIt ) {
         if ( typeIt.value() & ( *phoneIt ).type() ) {
-          line.addParameter( QLatin1String( "TYPE" ), typeIt.key() );
+            addParameter(line, version, QLatin1String( "TYPE" ), QStringList()<<typeIt.key());
         }
       }
 
@@ -401,6 +458,7 @@ QByteArray VCardTool::createVCards( const Addressee::List &list,
     card.addLine( titleLine );
 
     // TZ
+    // TODO Add vcard4.0 support
     const TimeZone timeZone = ( *addrIt ).timeZone();
     if ( timeZone.isValid() ) {
       QString str;
@@ -422,6 +480,10 @@ QByteArray VCardTool::createVCards( const Addressee::List &list,
 
     // URL
     card.addLine( VCardLine( QLatin1String( "URL" ), ( *addrIt ).url().url() ) );
+    Q_FOREACH (const KUrl &url, ( *addrIt ).extraUrlList()) {
+        VCardLine line = VCardLine( QLatin1String( "URL" ), url.url() );
+        card.addLine( line );
+    }
 
     // VERSION
     if ( version == VCard::v2_1 ) {
@@ -595,6 +657,24 @@ Addressee::List VCardTool::parseVCards( const QByteArray &vcard ) const
           const QStringList categories = splitString( commaSep, ( *lineIt ).value().toString() );
           addr.setCategories( categories );
         }
+        // FBURL
+        else if (identifier == QLatin1String( "fburl" ) ) {
+            CalendarUrl calendarUrl(CalendarUrl::FBUrl);
+            //TODO extract emails
+            addr.insertCalendarUrl(calendarUrl);
+        }
+        // CALADRURI
+        else if (identifier == QLatin1String( "caladruri" ) ) {
+            CalendarUrl calendarUrl(CalendarUrl::CALADRUri);
+            //TODO extract emails
+            addr.insertCalendarUrl(calendarUrl);
+        }
+        // CALURI
+        else if (identifier == QLatin1String( "caluri" ) ) {
+            CalendarUrl calendarUrl(CalendarUrl::CALUri);
+            //TODO extract emails
+            addr.insertCalendarUrl(calendarUrl);
+        }
 
         // CLASS
         else if ( identifier == QLatin1String( "class" ) ) {
@@ -700,7 +780,12 @@ Addressee::List VCardTool::parseVCards( const QByteArray &vcard ) const
 
         // LOGO
         else if ( identifier == QLatin1String( "logo" ) ) {
-          addr.setLogo( parsePicture( *lineIt ) );
+            Picture picture = parsePicture( *lineIt );
+            if (addr.logo().isEmpty()) {
+                addr.setLogo( picture );
+            } else {
+                addr.insertExtraLogo( picture );
+            }
         }
 
         // MAILER
@@ -763,7 +848,12 @@ Addressee::List VCardTool::parseVCards( const QByteArray &vcard ) const
 
         // PHOTO
         else if ( identifier == QLatin1String( "photo" ) ) {
-          addr.setPhoto( parsePicture( *lineIt ) );
+            Picture picture = parsePicture( *lineIt );
+            if (addr.photo().isEmpty()) {
+                addr.setPhoto( picture );
+            } else {
+                addr.insertExtraPhoto( picture );
+            }
         }
 
         // PROID
@@ -788,7 +878,12 @@ Addressee::List VCardTool::parseVCards( const QByteArray &vcard ) const
 
         // SOUND
         else if ( identifier == QLatin1String( "sound" ) ) {
-          addr.setSound( parseSound( *lineIt ) );
+            Sound sound = parseSound( *lineIt );
+            if (addr.sound().isEmpty()) {
+                addr.setSound( sound );
+            } else {
+                addr.insertExtraSound(sound);
+            }
         }
 
         // TEL
@@ -837,7 +932,25 @@ Addressee::List VCardTool::parseVCards( const QByteArray &vcard ) const
 
         // URL
         else if ( identifier == QLatin1String( "url" ) ) {
-          addr.setUrl( KUrl( ( *lineIt ).value().toString() ) );
+            const KUrl url = KUrl( ( *lineIt ).value().toString() );
+            if (addr.url().isEmpty()) {
+                addr.setUrl( url );
+            } else {
+                addr.insertExtraUrl(url);
+            }
+        }
+        // SOURCE
+        else if ( identifier == QLatin1String( "source" ) ) {
+            const KUrl url = KUrl( ( *lineIt ).value().toString() );
+            addr.insertSourceUrl( url );
+        }
+        // MEMBER (vcard 4.0)
+        else if ( identifier == QLatin1String( "member" ) ) {
+            addr.insertMember( ( *lineIt ).value().toString() );
+        }
+        // RELATED (vcard 4.0)
+        else if ( identifier == QLatin1String( "related" ) ) {
+            addr.insertRelationShip( ( *lineIt ).value().toString() );
         }
 
         // X-
@@ -998,7 +1111,6 @@ Picture VCardTool::parsePicture( const VCardLine &line ) const
 
 VCardLine VCardTool::createPicture( const QString &identifier, const Picture &pic, VCard::Version version ) const
 {
-  Q_UNUSED(version);
   VCardLine line( identifier );
 
   if ( pic.isEmpty() ) {
@@ -1007,8 +1119,13 @@ VCardLine VCardTool::createPicture( const QString &identifier, const Picture &pi
 
   if ( pic.isIntern() ) {
     line.setValue( pic.rawData() );
-    line.addParameter( QLatin1String( "encoding" ), QLatin1String( "b" ) );
-    line.addParameter( QLatin1String( "type" ), pic.type() );
+    if (version == VCard::v2_1) {
+        line.addParameter( QLatin1String( "ENCODING" ), QLatin1String( "BASE64" ) );
+        line.addParameter( pic.type(), QString() );
+    } else {
+        line.addParameter( QLatin1String( "encoding" ), QLatin1String( "b" ) );
+        line.addParameter( QLatin1String( "type" ), pic.type() );
+    }
   } else {
     line.setValue( pic.url() );
     line.addParameter( QLatin1String( "value" ), QLatin1String( "URI" ) );
@@ -1040,13 +1157,16 @@ Sound VCardTool::parseSound( const VCardLine &line ) const
 
 VCardLine VCardTool::createSound( const Sound &snd, VCard::Version version ) const
 {
-  Q_UNUSED(version);
   VCardLine line( QLatin1String( "SOUND" ) );
 
   if ( snd.isIntern() ) {
     if ( !snd.data().isEmpty() ) {
       line.setValue( snd.data() );
-      line.addParameter( QLatin1String( "encoding" ), QLatin1String( "b" ) );
+      if (version == VCard::v2_1) {
+          line.addParameter( QLatin1String( "ENCODING" ), QLatin1String( "BASE64" ) );
+      } else {
+          line.addParameter( QLatin1String( "encoding" ), QLatin1String( "b" ) );
+      }
       // TODO: need to store sound type!!!
     }
   } else if ( !snd.url().isEmpty() ) {
