@@ -97,7 +97,8 @@ QByteArray CompatibilityAttribute::type() const
 
 QByteArray CompatibilityAttribute::name()
 {
-    return "KAlarmCompatibility";
+    static const QByteArray attType("KAlarmCompatibility");
+    return attType;
 }
 
 QByteArray CompatibilityAttribute::serialized() const
